VButtonStyle class

Constructors

VButtonStyle({required VbuttonType type, required bool plain, required bool hairline, required VButtonShape shap, required VButtonSize size, required bool loading})

Properties

backgroundColor MaterialStateProperty<Color?>
no setter
foregroundColor MaterialStateProperty<Color?>
no setter
hairline bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
loading bool
getter/setter pair
loadingStatus Widget
no setter
minimumSize MaterialStateProperty<Size?>
no setter
overlayColor MaterialStateProperty<Color?>
no setter
padding MaterialStateProperty<EdgeInsets?>
no setter
plain bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shap VButtonShape
getter/setter pair
shape MaterialStateProperty<RoundedRectangleBorder?>
no setter
side MaterialStateProperty<BorderSide?>
no setter
size VButtonSize
getter/setter pair
textStyle MaterialStateProperty<TextStyle?>
no setter
type VbuttonType
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited